@@ -1,4 +1,5 @@
 use super::component::LoggerComponent;
+use crate::core::logger::message::Message;
 
 use std::fs::{create_dir, File, OpenOptions};
 use std::io::{Error, Write};
@@ -32,8 +33,8 @@ impl FileComponent {
 }
 
 impl LoggerComponent for FileComponent {
-    fn log(&mut self, msg: &str) -> Result<(), Error> {
-        match self.file.write(msg.as_bytes()) {
+    fn log(&mut self, msg: &Message) -> Result<(), Error> {
+        match self.file.write(msg.to_string().as_bytes()) {
             Ok(_) => Ok(()),
             Err(error) => Err(error),
         }
